@@ -6,6 +6,7 @@ from .config import *
 from .generators import *
 from .memory import *
 from .messages import *
+from .tools import Tool
 
 __all__ = [
     "MessageRole",
@@ -16,4 +17,5 @@ __all__ = [
     "TurboModel",
     "BaseMemory",
     "BaseCache",
+    "Tool",
 ]
