@@ -1,9 +1,11 @@
 # flake8: noqa
 # This is so ruff doesn't remove * imports
 
+from .template import *
 from .retries import *
 
 __all__ = [
+    "render_template",
     "create_retry_decorator",
     "with_retries",
 ]
